﻿using DepartmentBusinessLogic.BindingModels;
using DepartmentBusinessLogic.BusinessLogics;
using DepartmentBusinessLogic.ViewModels;
using DesktopTools.Controls;
using DesktopTools.Enums;
using DesktopTools.Helpers;
using DesktopTools.Interfaces;
using DesktopTools.Models;
using ModuleTools.Enums;
using System;
using System.Collections.Generic;

namespace DepartmentWindowsDesktop.EntityControls
{
    /// <summary>
    /// Реализация контрола для списка историй синхронизации приказов
    /// </summary>
    public partial class ControlOrderSyncHistoryList :
		GenericControlEntityList<OrderSyncHistoryGetBindingModel, OrderSyncHistorySetBindingModel, OrderSyncHistoryListViewModel, OrderSyncHistoryViewModel, OrderSyncHistoryBusinessLogic>,
		IGenericControlEntityList
	{
		public ControlOrderSyncHistoryList()
		{
			InitializeComponent();
			Title = "Синхронизация Приказов";
			ControlId = new Guid("7b857c17-405e-40fb-961f-7fe74fddf84e");
			AccessOperation = AccessOperation.СинхронизацияПриказов;
			ControlViewEntityElement = new ControlOrderSyncHistoryElement();
			_genericControlViewEntityList = this;
		}

		public IControl GetInstanceGenericControl() => new ControlOrderSyncHistoryList() { ControlId = Guid.NewGuid() };

		public ControlViewEntityListConfiguration GetConfigControl() => new()
		{
			PaginationOn = false,
			HideToolStripButton = new List<ToolStripButtonListNames>
			{
				ToolStripButtonListNames.toolStripButtonAdd,
				ToolStripButtonListNames.toolStripButtonUpd,
				ToolStripButtonListNames.toolStripButtonDel,
				ToolStripButtonListNames.toolStripButtonSearch
			},
			ControlOnMoveElem = new()
			{
				{ "ToolStripMenuItemSyncOrders", ("Синхронизировать студентов", (object sender, EventArgs e) => { SyncOrders(); }) }
			}
		};

		/// <summary>
		/// Синхронизация приказов
		/// </summary>
		/// <returns></returns>
		private void SyncOrders() 
		{
			var flag = _businessLogic.SyncOrders();
			if (!flag)
			{
				DialogHelper.MessageException(_businessLogic.Errors, "Ошибки при синхронизации");
			}
			else
			{
				DialogHelper.MessageInformation("Завершено успешно", "Синхронизация приказов");
			}
		}
	}
}